==> unimatrix.ext.crypto-0.11.1.tar.gz: unimatrix.ext.crypto-0.11.1/examples/trust-jwks.py <==
#!/usr/bin/env python3
import unimatrix.runtime
from unimatrix.ext import crypto
from unimatrix.ext.crypto import policy


async def main():
    await crypto.trust.load([
        {
            'loader': 'unimatrix.ext.crypto.loaders.WellKnownOAuthLoader',
            'tags': ['foo'],
            'annotations': {
                'greeting': 'Hello world!',
                'mynamespace/key': 'namespaced'
            },
            'opts': {
                'server': "https://id.realm.digitalcitizen.nl"
            }
        }
    ])
    key = crypto.trust[0]
    assert key in crypto.trust
    assert key.is_tagged('foo')
    assert key.is_annotated('greeting')
    assert key.is_annotated('key', 'mynamespace')
    assert key.get_annotation('key', 'mynamespace') == 'namespaced'

    # Define policies for the key.
    assert policy.IsTagged('foo') & key
    assert not policy.IsTagged('foo') ^ key

    # The policy must not match key
    assert policy.IsTagged('bar') ^ key
    assert not policy.IsTagged('bar') & key

    # Policies can be AND-ed
    assert policy.IsTagged('foo') & policy.HasAnnotation('greeting') & key

    # Policies can be OR-ed
    assert policy.IsTagged('foo') | policy.IsTagged('bar') & key

    # Policies can be negated
    assert ~policy.IsTagged('bar') & key

    # Policies can be conditionally applied
    assert ~policy.IsTagged('bar', tags=['foo']) & key

    # Shorthand for multiple policies
    assert policy.combine(policy.IsTagged('foo'), ~policy.IsTagged('bar')) & key

    # And more combinations
    assert ~policy.IsTagged('bar') & policy.IsTagged('foo') & key


if __name__ == '__main__':
    unimatrix.runtime.execute(main)

==> unimatrix.ext.crypto-0.12.5.tar.gz: unimatrix.ext.crypto-0.12.5/examples/trust-jwks.py <==
#!/usr/bin/env python3
import unimatrix.runtime
from unimatrix.ext import crypto
from unimatrix.ext.crypto import policy


async def main():
    await crypto.trust.load([
        {
            'loader': 'unimatrix.ext.crypto.loaders.JWKSLoader',
            'tags': ['foo'],
            'annotations': {
                'greeting': 'Hello world!',
                'mynamespace/key': 'namespaced'
            },
            'opts': {
                'url': "https://id.realm.digitalcitizen.nl/oauth2/jwks"
            }
        }
    ])
    key = crypto.trust[0]
    assert key in crypto.trust
    assert key.is_tagged('foo')
    assert key.is_annotated('greeting')
    assert key.is_annotated('key', 'mynamespace')
    assert key.get_annotation('key', 'mynamespace') == 'namespaced'

    # Define policies for the key.
    assert policy.IsTagged('foo') & key
    assert not policy.IsTagged('foo') ^ key

    # The policy must not match key
    assert policy.IsTagged('bar') ^ key
    assert not policy.IsTagged('bar') & key

    # Policies can be AND-ed
    assert policy.IsTagged('foo') & policy.HasAnnotation('greeting') & key

    # Policies can be OR-ed
    assert policy.IsTagged('foo') | policy.IsTagged('bar') & key

    # Policies can be negated
    assert ~policy.IsTagged('bar') & key

    # Policies can be conditionally applied
    assert ~policy.IsTagged('bar', tags=['foo']) & key

    # Shorthand for multiple policies
    assert policy.combine(policy.IsTagged('foo'), ~policy.IsTagged('bar')) & key

    # And more combinations
    assert ~policy.IsTagged('bar') & policy.IsTagged('foo') & key


if __name__ == '__main__':
    unimatrix.runtime.execute(main)
